# eric7.WebBrowser.GreaseMonkey.GreaseMonkeyConfiguration.GreaseMonkeyConfigurationScriptInfoDialog

Module implementing a dialog to show GreaseMonkey script information.

### Global Attributes

None

### Classes

GreaseMonkeyConfigurationScriptInfoDialog | Class implementing a dialog to show GreaseMonkey script information.

### Functions

None

## GreaseMonkeyConfigurationScriptInfoDialog

Class implementing a dialog to show GreaseMonkey script information.

### Derived from

QDialog, Ui_GreaseMonkeyConfigurationScriptInfoDialog

### Class Attributes

None

### Class Methods

None

### Methods

GreaseMonkeyConfigurationScriptInfoDialog | Constructor
on_showScriptSourceButton_clicked | Private slot to show an editor window with the script source code.

### Static Methods

None

#### GreaseMonkeyConfigurationScriptInfoDialog (Constructor)

GreaseMonkeyConfigurationScriptInfoDialog(script, parent=None)

Constructor

script
  reference to the script (GreaseMonkeyScript)
parent
  reference to the parent widget (QWidget)

#### GreaseMonkeyConfigurationScriptInfoDialog.on_showScriptSourceButton_clicked

on_showScriptSourceButton_clicked()

Private slot to show an editor window with the script source code.

Up